# Demo Screencast

Install `asciinema`, delete the existing `demo.cast`, then run `asciinema rec --command "./demo.sh" demo.cast`.

To convert the cast to a gif, install `asciicast2gif` then run `asciicast2gif demo.cast demo.gif`.
